/*******************************************************************************
* File Name: CLKIN.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "CLKIN.h"


/*******************************************************************************
* Function Name: CLKIN_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void CLKIN_Write(uint8 value)
{
    uint8 staticBits = CLKIN_DR & ~CLKIN_MASK;
    CLKIN_DR = staticBits | ((value << CLKIN_SHIFT) & CLKIN_MASK);
}


/*******************************************************************************
* Function Name: CLKIN_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void CLKIN_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(CLKIN_0, mode);
}


/*******************************************************************************
* Function Name: CLKIN_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CLKIN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CLKIN_Read(void)
{
    return (CLKIN_PS & CLKIN_MASK) >> CLKIN_SHIFT;
}


/*******************************************************************************
* Function Name: CLKIN_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CLKIN_ReadDataReg(void)
{
    return (CLKIN_DR & CLKIN_MASK) >> CLKIN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CLKIN_INTSTAT) 

    /*******************************************************************************
    * Function Name: CLKIN_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CLKIN_ClearInterrupt(void)
    {
        return (CLKIN_INTSTAT & CLKIN_MASK) >> CLKIN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
