/*******************************************************************************
* File Name: CapSense_1.h
* Version 1.30
*
* Description:
*  This file provides constants and parameter values for the CapSense
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAPSENSE_CapSense_1_H)
#define CY_CAPSENSE_CapSense_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cydevice_trm.h"
#include "CyLib.h"

#include "CapSense_1_sUDBPrescaler.h"
#include "CapSense_1_sbCSD_cRAW.h"
#include "CapSense_1_sbCSD_cComp.h"
#include "CapSense_1_sbCSD_cAMux.h"
#include "CapSense_1_sbCSD_cPWM.h"
#include "CapSense_1_sUDBSpeed.h"


/***************************************
*       Types definition
***************************************/

/*       Scan Slot struct             */
typedef struct _CapSense_1_Slot
{
    uint8 RawIndex;         /* Entry in SlotResult */
    uint8 IndexOffset;      /* Offset in IndezTable */
    uint8 SnsCnt;           /* Number of Sensors in currect Slot */
    uint8 WidgetNumber;     /* Number of Widget this slot belongs */
    uint8 DebounceCount;    /* Helps to define if slot Active */
} CapSense_1_Slot;

/*        Settings for CSD         */
typedef struct _CapSense_1_CSD_Settings
{
    uint8 PrescalerPeriod;      /* Prescaler for SW_CLK */
    uint8 Resolution;           /* PWM Resolution */
    uint8 ScanSpeed;            /* Speed of scanning  DIG_CLK */
    uint8 DisableState;         /* Disable state of ScanSlot */

} CapSense_1_CSD_Settings;

/*       Port Shift struct            */
typedef struct _CapSense_1_PortShift
{
    uint8 port;
    uint8 shift;
} CapSense_1_PortShift;


/***************************************
*        Function Prototypes
***************************************/

void CapSense_1_Start(void);
void CapSense_1_Stop(void);
void CapSense_1_ScanSlot(uint8 slot);
void CapSense_1_ScanAllSlots(void);

void CapSense_1_CSD_Start(void);
void CapSense_1_CSD_Stop(void);
void CapSense_1_CSD_ScanSlot(uint8 slot);
void CapSense_1_CSD_ScanAllSlots(void);
void CapSense_1_CSD_SetSlotSettings(uint8 slot);
void CapSense_1_CSD_ClearSlots(void);
void CapSense_1_CSD_EnableSensor(uint8 sensor);
void CapSense_1_CSD_DisableSensor(uint8 sensor, uint8 state);
uint16 CapSense_1_CSD_ReadSlot(uint8 slot);
void CapSense_1_CSD_SetRBleed(uint8 rbeed);
/* Interrupt handler */
CY_ISR_PROTO(CapSense_1_ISR);

extern uint8 CapSense_1_status;


/***************************************
*           API Constants
***************************************/

#define CapSense_1_TOTAL_SENSOR_COUNT              1
#define CapSense_1_TOTAL_SCANSLOT_COUNT            1
#define CapSense_1_TOTAL_GENERIC_SCANSLOT_COUNT    0

/* Define Sensors */
#define CapSense_1_SENSOR_PROX_PROXSENSE_0    0

/* Define ScanSlots */
#define CapSense_1_SCANSLOT_PROX_PROXSENSE    0

/* Chanels of CapSense */
#define CapSense_1_CMOD_CHANNEL          1
#define CapSense_1_CMP_VP_CHANNEL        2

#define CapSense_1_CSD_METHOD
#define CapSense_1_VREF_VDAC_VALUE        64

/* Scan Speed Type */
#define CapSense_1_SCAN_SPEED_ULTRA_FAST      0x01u
#define CapSense_1_SCAN_SPEED_FAST            0x03u
#define CapSense_1_SCAN_SPEED_NORMAL          0x07u
#define CapSense_1_SCAN_SPEED_SLOW            0x0Fu

/* Idac SetRange */
#define CapSense_1_IDAC_RANGE_MASK            0x0Cu
#define CapSense_1_IDAC_RANGE_32uA            0x00u
#define CapSense_1_IDAC_RANGE_255uA           0x04u
#define CapSense_1_IDAC_RANGE_2mA             0x08u

/* PWM Resolution */
#define CapSense_1_PWM_WINDOW_SHIFT           8u
#define CapSense_1_PWM_RESOLUTION_8_BITS      0x00u
#define CapSense_1_PWM_RESOLUTION_9_BITS      0x01u
#define CapSense_1_PWM_RESOLUTION_10_BITS     0x03u
#define CapSense_1_PWM_RESOLUTION_11_BITS     0x07u
#define CapSense_1_PWM_RESOLUTION_12_BITS     0x0Fu
#define CapSense_1_PWM_RESOLUTION_13_BITS     0x1Fu
#define CapSense_1_PWM_RESOLUTION_14_BITS     0x3Fu
#define CapSense_1_PWM_RESOLUTION_15_BITS     0x7Fu
#define CapSense_1_PWM_RESOLUTION_16_BITS     0xFFu

/* Enable csBuffer */
#define CapSense_1_CSBUF_BOOST_ENABLE         0x02u
#define CapSense_1_CSBUF_ENABLE               0x01u

/* Starts CapSensing */
#define CapSense_1_START_CAPSENSING           0x01u

/* Resets PWM and Raw Counter */
#define CapSense_1_RESET_PWM_CNTR             0x02u

/* Overfow of counter while CSA */
#define CapSense_1_RAW_OVERFLOW               0x04u

/* Turn off IDAC  */
#define CapSense_1_TURN_OFF_IDAC              0x00u

/* Rbleed */
#define CapSense_1_MAX_RB_NUMBER      3
#define CapSense_1_RBLEED1            0
#define CapSense_1_RBLEED2            1
#define CapSense_1_RBLEED3            2

/* Diasable States */
#define CapSense_1_DISABLE_STATE_GND          0
#define CapSense_1_DISABLE_STATE_HIGHZ        1
#define CapSense_1_DISABLE_STATE_SHIELD       2
#define CapSense_1_ALONE_SENSOR               1


/***************************************
*             Registers
***************************************/

/* Control Register */
#define CapSense_1_CONTROL             (* (reg8 *) CapSense_1_sbCSD_cControl_ctrl_reg__CONTROL_REG )

/* csBuffer */
#define CapSense_1_CAPS_CFG0           (* (reg8 *) CapSense_1_sbCSD_cBuf__CFG0 )
#define CapSense_1_CAPS_CFG1           (* (reg8 *) CapSense_1_sbCSD_cBuf__CFG1 )
#define CapSense_1_CSBUF_PWRMGR        (* (reg8 *) CapSense_1_sbCSD_cBuf__PM_ACT_CFG )
#define CapSense_1_CSBUF_PWR_ENABLE    CapSense_1_sbCSD_cBuf__PM_ACT_MSK

/* ISR Number and Priority to work with CyLib functions */
#define CapSense_1_ISR_NUMBER        CapSense_1_sbCSD_cISR__INTC_NUMBER
#define CapSense_1_ISR_PRIORITY      CapSense_1_sbCSD_cISR__INTC_PRIOR_NUM

#if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
    #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (CapSense_1_sbCSD_cISR__ES2_PATCH))
        #include <intrins.h>
        #define CapSense_1_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
    #endif
#endif

/* Register to work with port */
#define CapSense_1_BASE_PRT_PC            ( (reg8 *) CYDEV_IO_PC_PRT0_BASE )
#if((CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD) && (CYDEV_CHIP_REV_EXPECT == CYDEV_CHIP_REV_LEOPARD_ES1))
    #define CapSense_1_BASE_PRTDSI_CAPS   ( (reg8 *) CYREG_PRTDSI_PRT0_CAPS_SEL )
#else
    #define CapSense_1_BASE_PRTDSI_CAPS   ( (reg8 *) CYREG_PRT0_CAPS_SEL )
#endif


/***************************************
*       Register Constants
***************************************/

/* PC and CAPS_SEL Registers Offset */
#define CapSense_1_PRT_PC_OFFSET      CYDEV_IO_PC_PRT0_SIZE
#define CapSense_1_PRTDSI_OFFSET      (CYDEV_PRTDSI_PRT0_SIZE+1)

/* Masks of PTR PC Register */
#define CapSense_1_DR_MASK            0x01
#define CapSense_1_DM0_MASK           0x02
#define CapSense_1_DM1_MASK           0x04
#define CapSense_1_DM2_MASK           0x08
#define CapSense_1_BYP_MASK           0x80

#define CapSense_1_PRT_PC_GND         CapSense_1_DM2_MASK
#define CapSense_1_PRT_PC_HIGHZ       (CapSense_1_DM2_MASK |CapSense_1_DR_MASK)
#define CapSense_1_PRT_PC_SHIELD      (CapSense_1_DM2_MASK | CapSense_1_DM1_MASK | CapSense_1_BYP_MASK)

#endif /* End CY_CAPSENSE_CapSense_1_H */


 /* [] END OF FILE */
