/*******************************************************************************
* File Name: DBOUT.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DBOUT.h"


/*******************************************************************************
* Function Name: DBOUT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DBOUT_Write(uint8 value)
{
    uint8 staticBits = DBOUT_DR & ~DBOUT_MASK;
    DBOUT_DR = staticBits | ((value << DBOUT_SHIFT) & DBOUT_MASK);
}


/*******************************************************************************
* Function Name: DBOUT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DBOUT_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(DBOUT_0, mode);
}


/*******************************************************************************
* Function Name: DBOUT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DBOUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DBOUT_Read(void)
{
    return (DBOUT_PS & DBOUT_MASK) >> DBOUT_SHIFT;
}


/*******************************************************************************
* Function Name: DBOUT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DBOUT_ReadDataReg(void)
{
    return (DBOUT_DR & DBOUT_MASK) >> DBOUT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DBOUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: DBOUT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DBOUT_ClearInterrupt(void)
    {
        return (DBOUT_INTSTAT & DBOUT_MASK) >> DBOUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
