/*******************************************************************************
* File Name: DGOUT.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DGOUT.h"


/*******************************************************************************
* Function Name: DGOUT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DGOUT_Write(uint8 value)
{
    uint8 staticBits = DGOUT_DR & ~DGOUT_MASK;
    DGOUT_DR = staticBits | ((value << DGOUT_SHIFT) & DGOUT_MASK);
}


/*******************************************************************************
* Function Name: DGOUT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DGOUT_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(DGOUT_0, mode);
}


/*******************************************************************************
* Function Name: DGOUT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DGOUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DGOUT_Read(void)
{
    return (DGOUT_PS & DGOUT_MASK) >> DGOUT_SHIFT;
}


/*******************************************************************************
* Function Name: DGOUT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DGOUT_ReadDataReg(void)
{
    return (DGOUT_DR & DGOUT_MASK) >> DGOUT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DGOUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: DGOUT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DGOUT_ClearInterrupt(void)
    {
        return (DGOUT_INTSTAT & DGOUT_MASK) >> DGOUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
