/*******************************************************************************
* File Name: DROUT.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DROUT.h"


/*******************************************************************************
* Function Name: DROUT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DROUT_Write(uint8 value)
{
    uint8 staticBits = DROUT_DR & ~DROUT_MASK;
    DROUT_DR = staticBits | ((value << DROUT_SHIFT) & DROUT_MASK);
}


/*******************************************************************************
* Function Name: DROUT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DROUT_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(DROUT_0, mode);
}


/*******************************************************************************
* Function Name: DROUT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DROUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DROUT_Read(void)
{
    return (DROUT_PS & DROUT_MASK) >> DROUT_SHIFT;
}


/*******************************************************************************
* Function Name: DROUT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DROUT_ReadDataReg(void)
{
    return (DROUT_DR & DROUT_MASK) >> DROUT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DROUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: DROUT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DROUT_ClearInterrupt(void)
    {
        return (DROUT_INTSTAT & DROUT_MASK) >> DROUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
