/*******************************************************************************
* File Name: LOADOUT.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "LOADOUT.h"


/*******************************************************************************
* Function Name: LOADOUT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void LOADOUT_Write(uint8 value)
{
    uint8 staticBits = LOADOUT_DR & ~LOADOUT_MASK;
    LOADOUT_DR = staticBits | ((value << LOADOUT_SHIFT) & LOADOUT_MASK);
}


/*******************************************************************************
* Function Name: LOADOUT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void LOADOUT_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(LOADOUT_0, mode);
}


/*******************************************************************************
* Function Name: LOADOUT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro LOADOUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 LOADOUT_Read(void)
{
    return (LOADOUT_PS & LOADOUT_MASK) >> LOADOUT_SHIFT;
}


/*******************************************************************************
* Function Name: LOADOUT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 LOADOUT_ReadDataReg(void)
{
    return (LOADOUT_DR & LOADOUT_MASK) >> LOADOUT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(LOADOUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: LOADOUT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 LOADOUT_ClearInterrupt(void)
    {
        return (LOADOUT_INTSTAT & LOADOUT_MASK) >> LOADOUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
