/*******************************************************************************
* File Name: CLK_IN.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "CLK_IN.h"


/*******************************************************************************
* Function Name: CLK_IN_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void CLK_IN_Write(uint8 value)
{
    uint8 staticBits = CLK_IN_DR & ~CLK_IN_MASK;
    CLK_IN_DR = staticBits | ((value << CLK_IN_SHIFT) & CLK_IN_MASK);
}


/*******************************************************************************
* Function Name: CLK_IN_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void CLK_IN_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(CLK_IN_0, mode);
}


/*******************************************************************************
* Function Name: CLK_IN_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CLK_IN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CLK_IN_Read(void)
{
    return (CLK_IN_PS & CLK_IN_MASK) >> CLK_IN_SHIFT;
}


/*******************************************************************************
* Function Name: CLK_IN_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CLK_IN_ReadDataReg(void)
{
    return (CLK_IN_DR & CLK_IN_MASK) >> CLK_IN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CLK_IN_INTSTAT) 

    /*******************************************************************************
    * Function Name: CLK_IN_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CLK_IN_ClearInterrupt(void)
    {
        return (CLK_IN_INTSTAT & CLK_IN_MASK) >> CLK_IN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
