/*******************************************************************************
* File Name: CapSense_1.c
* Version 1.30
*
* Description:
*  This file provides the source code to the API for the CapSense Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CapSense_1.h"

CapSense_1_Slot CapSense_1_ScanSlotTable[] = 
{
    {0, 0, 1, 0, 0}
};

const uint8 CapSense_1_IndexTable[] = { 0x00 };

CapSense_1_CSD_Settings CapSense_1_SettingsTable[] = 
{
    {15, CapSense_1_PWM_RESOLUTION_16_BITS, CapSense_1_SCAN_SPEED_NORMAL, CapSense_1_DISABLE_STATE_HIGHZ}
};

const CapSense_1_PortShift CapSense_1_PortShiftTable[] = 
{
    {CapSense_1_sbCSD_cPort__PROX_ProxSense_0__PORT, CapSense_1_sbCSD_cPort__PROX_ProxSense_0__SHIFT}
};

/* Different for Left and Right sides */
reg8 *CapSense_1_RbPortPinTable[] = 
{
    (reg8 *) CapSense_1_sbCSD_cRb0__sRb0__PC
};

uint8 CapSense_1_currentRbleed = CapSense_1_MAX_RB_NUMBER;

uint8 CapSense_1_status = 0;

uint8 CapSense_1_idacInitVar = 0;

uint16 CapSense_1_SlotResult[CapSense_1_TOTAL_SCANSLOT_COUNT] = {0};
uint16 *CapSense_1_SlotRaw = CapSense_1_SlotResult;


/*******************************************************************************
* Function Name: CapSense_1_Start
********************************************************************************
*
* Summary:
*  Initializes registers for each module and starts the component. This function
*  calls functions automatically depending on modules selected in the
*  customizer. This function should be called prior to calling any other
*  component functions.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_Start(void)
{
    CapSense_1_CSD_Start();
}


/*******************************************************************************
* Function Name: CapSense_1_Stop
********************************************************************************
*
* Summary:
*  Stops the slot scanner, disables interrupts, and resets all slots to an 
*  inactive state
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_Stop(void)
{
    CapSense_1_CSD_Stop();
}


/*******************************************************************************
* Function Name: CapSense_1_ScanSlot
********************************************************************************
*
* Summary:
*  Calls the function CapSense_1_CSD_ScanSlot and scans defined scan slot.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_ScanSlot(uint8 slot)
{
      CapSense_1_CSD_ScanSlot(slot);
}


/*******************************************************************************
* Function Name: CapSense_1_ScanAllSlots
********************************************************************************
*
* Summary:
*  Scans all slots by calling CapSense_1_CSD_ScanAllSlots function for method
*  selected in customizer.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_ScanAllSlots(void)
{
    CapSense_1_CSD_ScanAllSlots();
}


/*******************************************************************************
* Function Name: CapSense_1_sbCSD_InitRb
********************************************************************************
*
* Summary:
*  Sets all Rbleed resistor to High-Z mode. Sets current Rbleed as first.
*
* Parameters:
*  void
*
* Return:
*  void
*
********************************************************************************/
void CapSense_1_sbCSD_InitRb(void)
{
    uint8 i;
    uint8 rbCount = sizeof(CapSense_1_RbPortPinTable)/sizeof(reg8 *);
    
    /* Disable all Rb */
    for(i=0; i < rbCount; i++)
    {
        /* Make High-Z */
        *CapSense_1_RbPortPinTable[i] = CapSense_1_PRT_PC_HIGHZ;
    }
    
    CapSense_1_currentRbleed = CapSense_1_RBLEED1;
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_SetRBleed
********************************************************************************
*
* Summary:
*  Sets the pin to use for the bleed resistor (Rb) connection. The function
*  overwrites the component parameter setting. This function is available only
*  if Rb configuration is defined by the CapSense customizer.
* 
* Parameters:
*  rbleed:  Ordering number for bleed resistor terminal defined in CapSense
*  customizer.
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_SetRBleed(uint8 rbleed)
{
    CapSense_1_currentRbleed = rbleed;
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_Start
********************************************************************************
*
* Summary:
*  Initializes registers and starts the CapSense Component.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_Start(void)
{
    
    /* Setup SW_CLK_Div_Serial */
    CapSense_1_sUDBPrescaler_Start();
    
    /* Setup DIG_CLK_DivSerial */
    CapSense_1_sUDBSpeed_Start();
    
    /* Setup sbCSD_csRawCnt */
    CapSense_1_sbCSD_cRAW_Start();
    
    /* Setup sbCSD_csPWM */
    CapSense_1_sbCSD_cPWM_Start();
    
    /* Enable Comparator */
    CapSense_1_sbCSD_cComp_Start();
    
    /* Initialize AMux */
    CapSense_1_sbCSD_cAMux_Start();
    
    /* Connect Cmod, Cmp, Idac */
    CapSense_1_sbCSD_cAMux_Connect(CapSense_1_CMOD_CHANNEL);
    CapSense_1_sbCSD_cAMux_Connect(CapSense_1_CMP_VP_CHANNEL);
    
    /* Enable Rbleed */
    CapSense_1_sbCSD_InitRb();
    
    /* Clear all Sensor */
    CapSense_1_CSD_ClearSlots();
    
    /* Setup ISR Component for CapSense */
    CyIntDisable(CapSense_1_ISR_NUMBER);
    CyIntSetVector(CapSense_1_ISR_NUMBER, CapSense_1_ISR);
    CyIntSetPriority(CapSense_1_ISR_NUMBER, CapSense_1_ISR_PRIORITY);
    CyIntEnable(CapSense_1_ISR_NUMBER);
    
    /* Enable csBuf */
    CapSense_1_CSBUF_PWRMGR |= CapSense_1_CSBUF_PWR_ENABLE;
    CapSense_1_CAPS_CFG0 |= CapSense_1_CSBUF_ENABLE;
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_Stop
********************************************************************************
*
* Summary:
*  Stops the slot scanner, disables internal interrupts, and calls 
*  CSD_ClearSlots() to reset all slots to an inactive state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_Stop(void)
{
    /* Stop Capsensing */
    CapSense_1_CONTROL &= ~CapSense_1_START_CAPSENSING;
    
    /* Disable the CapSense interrupt */
    CyIntEnable(CapSense_1_ISR_NUMBER);
    
    /* Clear all Sensor */
    CapSense_1_CSD_ClearSlots();
    
    /* Disable Comparator */
    CapSense_1_sbCSD_cComp_Stop();
    
    /* Disable csBuf */
    CapSense_1_CAPS_CFG0 &= ~CapSense_1_CSBUF_ENABLE;
    CapSense_1_CSBUF_PWRMGR &= ~CapSense_1_CSBUF_PWR_ENABLE;
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_ScanSlot
********************************************************************************
*
* Summary:
*  Sets scan settings and scans the selected scan slot. Each scan slot has
*  a unique number within the slot array. This number is assigned by the
*  CapSense customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_ScanSlot(uint8 slot)
{
    uint8 i, s, state;
    uint8 maxSns = CapSense_1_ScanSlotTable[slot].SnsCnt;
    uint8 startIndex = CapSense_1_ScanSlotTable[slot].IndexOffset;
    uint8 rawIndex = CapSense_1_ScanSlotTable[slot].RawIndex; 
    
    /* Set Slot Settings */
    CapSense_1_CSD_SetSlotSettings(slot);
    
    /* Disable CapSense Buffer */
    CapSense_1_CAPS_CFG0 &= ~CapSense_1_CSBUF_ENABLE;    
    
    /* Connect DSI output to Rb */
    *CapSense_1_RbPortPinTable[CapSense_1_currentRbleed] |= CapSense_1_BYP_MASK;
    
    /* Enable Sensors */
    if (maxSns == CapSense_1_ALONE_SENSOR)
    {
        CapSense_1_CSD_EnableSensor(startIndex);
    }
    else
    {
        for(i=0; i < maxSns; i++)
        {
            s = CapSense_1_IndexTable[startIndex+i];
            CapSense_1_CSD_EnableSensor(s);
        }
    }
    
    /* Set Flag CapSensing in progres */
    CapSense_1_status |= CapSense_1_START_CAPSENSING;
    
    /* Start PWM One Shout and PRS at one time */
    CapSense_1_CONTROL |= CapSense_1_START_CAPSENSING;
    
    /* Wait for finish CapSensing */
    while (CapSense_1_status == CapSense_1_START_CAPSENSING)
    { ; }
    
    /* Stop Capsensing */
    CapSense_1_CONTROL &= ~CapSense_1_START_CAPSENSING;
    
    /* Read SlotResult from RawCnt */
    CapSense_1_SlotResult[rawIndex] = CapSense_1_sbCSD_cRAW_ReadCounter();
    
    /* Disable Sensors */
    state = CapSense_1_SettingsTable[slot].DisableState;
    if (maxSns == CapSense_1_ALONE_SENSOR)
    {
        CapSense_1_CSD_DisableSensor(startIndex, state);
    }
    else
    {
        for(i=0; i < maxSns; i++)
        {
            s = CapSense_1_IndexTable[startIndex+i];
            CapSense_1_CSD_DisableSensor(s, state);
        }
    }
    
    /* Disconnect DSI output from Rb */
    *CapSense_1_RbPortPinTable[CapSense_1_currentRbleed] &= ~CapSense_1_BYP_MASK;
    
    /* Enable Vref on AMUX */
    CapSense_1_CAPS_CFG0 |= CapSense_1_CSBUF_ENABLE;
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_ScanAllSlots
********************************************************************************
*
* Summary:
*  Scans all scan slots by callingCapSense_1_CSD_ScanSlot for each
*  slot index.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_ScanAllSlots(void)
{
    uint8 i;
    
    for(i=0; i < CapSense_1_TOTAL_SCANSLOT_COUNT;i++)
    {
         CapSense_1_CSD_ScanSlot(i);
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_SetSlotSettings
********************************************************************************
*
* Summary:
*  Sets the scan settings of selected scan slot. Each setting has a unique
*  number within the settings array and is connected to corresponding scan slot.
*  This number is assigned by the CapSense customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_SetSlotSettings(uint8 slot)
{
    uint8 scanSpeed = CapSense_1_SettingsTable[slot].ScanSpeed;
    uint16 resolution = ((uint16) CapSense_1_SettingsTable[slot].Resolution << CapSense_1_PWM_WINDOW_SHIFT)\
                        | CapSense_1_PWM_RESOLUTION_16_BITS;
    uint8 prescalerPeriod = CapSense_1_SettingsTable[slot].PrescalerPeriod;
    
    /* PWM Resolution */
    CapSense_1_sbCSD_cPWM_WritePeriod(resolution);
    CapSense_1_sbCSD_cPWM_WriteCompare(resolution);
    
    /* Reset RawCnt and rearm PWM */
    CapSense_1_CONTROL |= CapSense_1_RESET_PWM_CNTR;
    
    /* Set ScanSpeed */
    CapSense_1_sUDBSpeed_Stop();
    CapSense_1_sUDBSpeed_WriteCounter(scanSpeed);
    CapSense_1_sUDBSpeed_WritePeriod(scanSpeed);
    CapSense_1_sUDBSpeed_Start();
    
    CapSense_1_CONTROL &= ~CapSense_1_RESET_PWM_CNTR;
    
    /* Set Prescaller */
    CapSense_1_sUDBPrescaler_Stop();
    CapSense_1_sUDBPrescaler_WriteCounter(prescalerPeriod);
    CapSense_1_sUDBPrescaler_WritePeriod(prescalerPeriod);
    CapSense_1_sUDBPrescaler_WriteCompare(prescalerPeriod/2);
    CapSense_1_sUDBPrescaler_Start();
    
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_ClearSlots
********************************************************************************
*
* Summary:
*  Clears all slots to the non-sampling state by sequentially disconnecting all
*  slots from Analog MUX Bus, disable pin global control and connecting them to
*  GND or Shield electrode.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_ClearSlots(void)
{
    uint8 i, s, j;
    uint8 startIndex, maxSns, state;
    
    for (i=0; i < CapSense_1_TOTAL_SCANSLOT_COUNT; i++)
    {
        startIndex = CapSense_1_ScanSlotTable[i].IndexOffset;
        maxSns = CapSense_1_ScanSlotTable[i].SnsCnt;
        state = CapSense_1_SettingsTable[i].DisableState;
        
        /* Disable Sensors */
        if (maxSns == CapSense_1_ALONE_SENSOR)
        {
            CapSense_1_CSD_DisableSensor(startIndex, state);
        }
        else
        {
            for(j=0; j < maxSns; j++)
            {
                s = CapSense_1_IndexTable[startIndex+j];
                CapSense_1_CSD_DisableSensor(s, state);
            }
        }
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_ReadSlot
********************************************************************************
*
* Summary:
*  Returns scan slot raw data from the SlotResult[] array. Each scan slot has a
*  unique number within the slot array. This number is assigned by the CapSense
*  customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  Returns current raw data value for defined scan slot
*
*******************************************************************************/
uint16 CapSense_1_CSD_ReadSlot(uint8 slot)
{
    uint8 index = CapSense_1_ScanSlotTable[slot].RawIndex;
    
    return CapSense_1_SlotResult[index];
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_EnableSensor
********************************************************************************
*
* Summary:
*  Configures the selected sensor to measure during the next measurement cycle.
*  The corresponding pins are set to Analog High-Z mode and connected to the
*  Analog Mux Bus. This also enables the comparator function.
*
* Parameters:
*  sensor:  Sensor number
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_EnableSensor(uint8 sensor)
{
    uint8 port = CapSense_1_PortShiftTable[sensor].port;
    uint8 shift = CapSense_1_PortShiftTable[sensor].shift;
    uint8 mask = 1;
    
    mask <<= shift;
    
    /* Make sensor High-Z */
    *(CapSense_1_BASE_PRT_PC + (CapSense_1_PRT_PC_OFFSET*port) + shift) = CapSense_1_PRT_PC_HIGHZ;
    
    /* Connect from DSI output */
    *(CapSense_1_BASE_PRTDSI_CAPS + (CapSense_1_PRTDSI_OFFSET*port)) |= mask;
    
    /* Connect to AMUX */
    CapSense_1_sbCSD_cAMux_Connect(sensor);    
}


/*******************************************************************************
* Function Name: CapSense_1_CSD_DisableSensor
********************************************************************************
*
* Summary:
*  Disables the selected sensor. The corresponding pin is disconnected from the
*  Analog Mux Bus and connected to GND, High_Z or Shield electrode.
*
* Parameters:
*  sensor:  Sensor number
*  state:  State of sensor when disabled
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSD_DisableSensor(uint8 sensor, uint8 state)
{
    uint8 port = CapSense_1_PortShiftTable[sensor].port;
    uint8 shift = CapSense_1_PortShiftTable[sensor].shift;
    uint8 mask = 1;
    
    mask <<= shift;
    
    /* Disconnect from AMUX */
    CapSense_1_sbCSD_cAMux_Disconnect(sensor);
    
    /* Connect from DSI output */
    *(CapSense_1_BASE_PRTDSI_CAPS + (CapSense_1_PRTDSI_OFFSET*port)) &= ~mask;
    
    switch(state)
    {
        case CapSense_1_DISABLE_STATE_GND:
            *(CapSense_1_BASE_PRT_PC + (CapSense_1_PRT_PC_OFFSET*port) + shift) = CapSense_1_PRT_PC_GND;
        break;
        
        case CapSense_1_DISABLE_STATE_HIGHZ:
            *(CapSense_1_BASE_PRT_PC + (CapSense_1_PRT_PC_OFFSET*port) + shift) = CapSense_1_PRT_PC_HIGHZ;
        break;
        
        case CapSense_1_DISABLE_STATE_SHIELD:
            *(CapSense_1_BASE_PRT_PC + (CapSense_1_PRT_PC_OFFSET*port) + shift) = CapSense_1_PRT_PC_SHIELD;
        break;
        
        default:
            *(CapSense_1_BASE_PRT_PC + (CapSense_1_PRT_PC_OFFSET*port) + shift) = CapSense_1_PRT_PC_GND;
        break;
    }
}


/* [] END OF FILE */
