/*******************************************************************************
* File Name: CapSense_1.c
* Version 1.30
*
* Description:
*  This file provides the source code to the High Level API for the CapSesne
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CapSense_1_CSHL.h"


CapSense_1_BtnSettings CapSense_1_BtnSettingsTable[1] = 
{
    {0, 0, 0, 0, 0, 0}
};

CapSense_1_Widget CapSense_1_CSHL_WidgetTable[] = 
{
    {CapSense_1_CSHL_TYPE_PROXIMITY, 0, 1, 15, 5, 5, 0, 1, &CapSense_1_BtnSettingsTable[0]}
};
extern CapSense_1_Slot CapSense_1_ScanSlotTable[CapSense_1_TOTAL_SCANSLOT_COUNT]; 
extern uint16 CapSense_1_SlotResult[CapSense_1_TOTAL_SCANSLOT_COUNT];

uint8 CapSense_1_CSHL_SlotOnMask[(((CapSense_1_TOTAL_SCANSLOT_COUNT - 1) / 8) + 1)] = {0};
uint16 CapSense_1_CSHL_SlotBaseline[CapSense_1_TOTAL_SCANSLOT_COUNT] = {0};
uint8 CapSense_1_CSHL_SlotBaselineLow[CapSense_1_TOTAL_SCANSLOT_COUNT] = {0};
uint8 CapSense_1_CSHL_SlotSignal[CapSense_1_TOTAL_SCANSLOT_COUNT] = {0};


/*******************************************************************************
* Function Name: CapSense_1_CSHL_MedianFilter
********************************************************************************
*
* Summary:
*  Median filter funciton.
*
* Parameters:
*  x1:  Current value
*  x2:  Previous value
*  x3:  Before previous value
*
* Return:
*  Returns filtered value.
*
*******************************************************************************/
uint16 CapSense_1_CSHL_MedianFilter(uint16 x1, uint16 x2, uint16 x3)
{
    uint16 tmp;

    if (x1 > x2)
    {
        tmp = x2;
        x2 = x1;
        x1 = tmp;
    }

    if(x2 > x3)
    {
        x2 = x3;
    }

    return ((x1 > x2) ? x1 : x2);
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_AveragingFilter
********************************************************************************
*
* Summary:
*  Averaging filter function.
*
* Parameters:
*  x1:  Current value
*  x2:  Previous value
*  x3:  Before previous value
*
* Return:
*  Returns filtered value.
*
*******************************************************************************/
uint16 CapSense_1_CSHL_AveragingFilter(uint16 x1, uint16 x2, uint16 x3)
{
    uint32 tmp = ((uint32)x1 + (uint32)x2 + (uint32)x3)/3;

    return ((uint16) tmp);
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_IIRFilter
********************************************************************************
*
* Summary:
*  IIR filter function.
*
* Parameters:
*  x1:  Current value
*  x2:  Previous value
*  type:  Type formula of IIR filter.
*
* Return:
*  Returns filtered value.
*
*******************************************************************************/
uint16 CapSense_1_CSHL_IIRFilter(uint16 x1, uint16 x2, uint8 type)
{
    uint32 tmp;

    if (type == CapSense_1_CSHL_IIR_FILTER_0)
    {
        /* IIR = 1/2 Current Value+ 1/2 Previous Value */
        tmp = (uint32)x1 + (uint32)x2;
        tmp >>= 1;
    }
    else
    {
        /* IIR = 1/4 Current Value + 3/4 Previous Value */
        tmp = (uint32)x1 + (uint32)x2;
        tmp += ((uint32)x2 << 1);
        tmp >>= 2;
    }

    return ((uint16) tmp);
}


/*******************************************************************************
* Function Name: uint16 CapSense_1_CSHL_JitterFilter
********************************************************************************
*
* Summary:
*  Jitter filter funciton.
*
* Parameters:
*  x1:  Current value
*  x2:  Previous value
*
* Return:
*  Returns filtered value.
*
*******************************************************************************/
uint16 CapSense_1_CSHL_JitterFilter(uint16 x1, uint16 x2)
{
    if (x1 > x2)
    {
        x1--;
    }
    else
    {
        if (x1 < x2)
        {
            x1++;
        }
    }

    return x1;
}

/*******************************************************************************
* Function Name: CapSense_1_CSHL_InitializeSlotBaseline
********************************************************************************
*
* Summary:
*  Loads the CapSense_1_CSHL_SlotBaseline[slot] array element with an initial
*  value by scanning the selected slot. The raw count value is copied into
*  the baseline array for each slot. The raw data filters are initialized
*  if enabled.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSHL_InitializeSlotBaseline(uint8 slot)
{
    void *ptr;
    uint8 rawIndex = CapSense_1_ScanSlotTable[slot].RawIndex;
    uint8 widget = CapSense_1_ScanSlotTable[slot].WidgetNumber;
    uint8 filterPos = rawIndex - CapSense_1_CSHL_WidgetTable[widget].RawOffset;
    
    if( widget != CapSense_1_CSHL_NO_WIDGET)
    {
        /* Scan slot to have raw data */
        CapSense_1_CSD_ScanSlot(slot);
        
        /* Initialize Baseline */
        CapSense_1_CSHL_SlotBaseline[rawIndex] = CapSense_1_SlotResult[rawIndex];
        CapSense_1_CSHL_SlotBaselineLow[rawIndex] = 0;
        CapSense_1_CSHL_SlotSignal[rawIndex] = 0;
        CapSense_1_ScanSlotTable[slot].DebounceCount = CapSense_1_CSHL_WidgetTable[widget].Debounce;
        
        switch ((CapSense_1_CSHL_WidgetTable[widget].Type & (~CapSense_1_CSHL_IS_DIPLEX)))
        {
            /* This case include BTN and PROX */
            case CapSense_1_CSHL_TYPE_BUTTON:
            case CapSense_1_CSHL_TYPE_PROXIMITY:
                if (CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings)
                {
                    ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                    
                    /* Median filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                    {
                        ((CapSense_1_BtnSettings *) ptr)->Raw2Median = CapSense_1_SlotResult[rawIndex];
                        ((CapSense_1_BtnSettings *) ptr)->Raw1Median = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* Averaging filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                    {
                        ((CapSense_1_BtnSettings *) ptr)->Raw2Averaging = CapSense_1_SlotResult[rawIndex];
                        ((CapSense_1_BtnSettings *) ptr)->Raw1Averaging = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* IIR filter first time initialization */
                    if((CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0) ||
                        (CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1))
                    {
                        ((CapSense_1_BtnSettings *) ptr)->RawIIR = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* Jitter filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                    {
                        ((CapSense_1_BtnSettings *) ptr)->RawJitter = CapSense_1_SlotResult[rawIndex];
                    }
                }
                break;
            
            /* This case include LINEAR and RADIAL Slider */
            case CapSense_1_CSHL_TYPE_RADIAL_SLIDER :
            case CapSense_1_CSHL_TYPE_LINEAR_SLIDER :
                
                ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                ((CapSense_1_SlSettings *) ptr)->FirstTime=0;
                
                /* Median filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                {
                    ((CapSense_1_SlSettings *) ptr)->Raw2Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                    ((CapSense_1_SlSettings *) ptr)->Raw1Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* Averaging filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                {
                    ((CapSense_1_SlSettings *) ptr)->Raw2Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                    ((CapSense_1_SlSettings *) ptr)->Raw1Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* IIR filter first time initialization */
                if((CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0) ||
                    (CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1))
                {
                    ((CapSense_1_SlSettings *) ptr)->RawIIR[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* Jitter filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                {
                    ((CapSense_1_SlSettings *) ptr)->RawJitter[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                break;
                
            case CapSense_1_CSHL_TYPE_TOUCHPAD:
                
                ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                ((CapSense_1_TPSettings *) ptr)->FirstTime=0;
                
                /* Median filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                {
                    ((CapSense_1_TPSettings *) ptr)->Raw2Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                    ((CapSense_1_TPSettings *) ptr)->Raw1Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* Averaging filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                {
                    ((CapSense_1_TPSettings *) ptr)->Raw2Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                    ((CapSense_1_TPSettings *) ptr)->Raw1Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* IIR filter first time initialization */
                if((CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0) ||
                    (CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1))
                {
                    ((CapSense_1_TPSettings *) ptr)->RawIIR[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                
                /* Jitter filter first time initialization */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                {
                    ((CapSense_1_TPSettings *) ptr)->RawJitter[filterPos] = CapSense_1_SlotResult[rawIndex];
                }
                break;
                
            case CapSense_1_CSHL_TYPE_MATRIX_BUTTONS:
                
                if (CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings)
                {
                    ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                    
                    /* Median filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                    {
                        ((CapSense_1_MBSettings *) ptr)->Raw2Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                    (   (CapSense_1_MBSettings *) ptr)->Raw1Median[filterPos] = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* Averaging filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                    {
                        ((CapSense_1_MBSettings *) ptr)->Raw2Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                        ((CapSense_1_MBSettings *) ptr)->Raw1Averaging[filterPos] = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* IIR filter first time initialization */
                    if((CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0) ||
                        (CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1))
                    {
                        ((CapSense_1_MBSettings *) ptr)->RawIIR[filterPos] = CapSense_1_SlotResult[rawIndex];
                    }
                    
                    /* Jitter filter first time initialization */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                    {
                        ((CapSense_1_MBSettings *) ptr)->RawJitter[filterPos] = CapSense_1_SlotResult[rawIndex];
                    }
                }
                break;
                        
            default:
            
                break;
        }
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_InitializeAllBaselines
********************************************************************************
*
* Summary:
*  Uses the CapSense_1_CSHL_InitializeSlotBaselines function to
*  loads the CapSense_1_CSHL_SlotBaseline[ ] array with an initial values by
*  scanning all slots. The raw count values are copied into the baseline array
*  for all slots. The raw data filters are initialized if enabled.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSense_1_CSHL_InitializeAllBaselines(void)
{
    uint8 i;
    
    for(i = 0; i < CapSense_1_TOTAL_SCANSLOT_COUNT; i++)
    {
        CapSense_1_CSHL_InitializeSlotBaseline(i);
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_UpdateSlotBaseline
********************************************************************************
*
* Summary:
*  Updates the CapSense_1_CSHL_SlotBaseline[ ] array using the LP filter with
*  k = 256. The signal calculates the difference between raw count and baseline.
*  The baseline stops updating if signal is greater that zero.
*  Raw data filters are applied to the values if enabled.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
 void CapSense_1_CSHL_UpdateSlotBaseline(uint8 slot)
{
    void *ptr;
    uint8 rawIndex = CapSense_1_ScanSlotTable[slot].RawIndex;
    uint8 widget = CapSense_1_ScanSlotTable[slot].WidgetNumber;
    uint8 filterPos = rawIndex - CapSense_1_CSHL_WidgetTable[widget].RawOffset;
    uint16 filteredRawData = CapSense_1_SlotResult[rawIndex];
    int32 temp;
    uint16 baseRawData;
    
    if( widget != CapSense_1_CSHL_NO_WIDGET)
    {
        
        /* Do filtering */
        switch ((CapSense_1_CSHL_WidgetTable[widget].Type & (~CapSense_1_CSHL_IS_DIPLEX)))
        {
            /* This case include BTN and PROX */
            case CapSense_1_CSHL_TYPE_BUTTON:
            case CapSense_1_CSHL_TYPE_PROXIMITY:
                if(CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings)
                {
                    ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                    
                    /* Median filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_MedianFilter(filteredRawData, ((CapSense_1_BtnSettings *) ptr)->Raw1Median, ((CapSense_1_BtnSettings *) ptr)->Raw2Median);
                        ((CapSense_1_BtnSettings *) ptr)->Raw2Median = ((CapSense_1_BtnSettings *) ptr)->Raw1Median;
                        ((CapSense_1_BtnSettings *) ptr)->Raw1Median = baseRawData;
                    }
                    
                    /* Averaging filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_AveragingFilter(filteredRawData, ((CapSense_1_BtnSettings *) ptr)->Raw1Averaging, ((CapSense_1_BtnSettings *) ptr)->Raw2Averaging);
                        ((CapSense_1_BtnSettings *) ptr)->Raw2Averaging = ((CapSense_1_BtnSettings *) ptr)->Raw1Averaging;
                        ((CapSense_1_BtnSettings *) ptr)->Raw1Averaging = baseRawData;
                    }
                    
                    /* IIR filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_BtnSettings *) ptr)->RawIIR, CapSense_1_CSHL_IIR_FILTER_0);
                        ((CapSense_1_BtnSettings *) ptr)->RawIIR = baseRawData;
                    }
                    else if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_BtnSettings *) ptr)->RawIIR, CapSense_1_CSHL_IIR_FILTER_1);
                        ((CapSense_1_BtnSettings *) ptr)->RawIIR = baseRawData;
                    }
                    
                    /* Jitter filter*/
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_JitterFilter(filteredRawData, ((CapSense_1_BtnSettings *) ptr)->RawJitter);
                        ((CapSense_1_BtnSettings *) ptr)->RawJitter = baseRawData;
                    }
                }
                break;
            
            /* This case include LINEAR and RADIAL Slider */
            case CapSense_1_CSHL_TYPE_RADIAL_SLIDER :
            case CapSense_1_CSHL_TYPE_LINEAR_SLIDER :
                ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                
                /* Median filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_MedianFilter(filteredRawData, ((CapSense_1_SlSettings *) ptr)->Raw1Median[filterPos], ((CapSense_1_SlSettings *) ptr)->Raw2Median[filterPos]);
                    ((CapSense_1_SlSettings *) ptr)->Raw2Median[filterPos] = ((CapSense_1_SlSettings *) ptr)->Raw1Median[filterPos];
                    ((CapSense_1_SlSettings *) ptr)->Raw1Median[filterPos] = baseRawData;
                }
                
                /* Averaging filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                {
                    baseRawData = filteredRawData;
                       filteredRawData = CapSense_1_CSHL_AveragingFilter(filteredRawData, ((CapSense_1_SlSettings *) ptr)->Raw1Averaging[filterPos], ((CapSense_1_SlSettings *) ptr)->Raw2Averaging[filterPos]);
                    ((CapSense_1_SlSettings *) ptr)->Raw2Averaging[filterPos] = ((CapSense_1_SlSettings *) ptr)->Raw1Averaging[filterPos];
                    ((CapSense_1_SlSettings *) ptr)->Raw1Averaging[filterPos] = baseRawData;
                }
                
                /* IIR filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_SlSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_0);
                    ((CapSense_1_SlSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                }
                else if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_SlSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_1);
                    ((CapSense_1_SlSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                }
                
                /* Jitter filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_JitterFilter(filteredRawData, ((CapSense_1_SlSettings *) ptr)->RawJitter[filterPos]);
                    ((CapSense_1_SlSettings *) ptr)->RawJitter[filterPos] = baseRawData;
                }
                break;
                
            case CapSense_1_CSHL_TYPE_TOUCHPAD:
                ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                
                /* Median filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_MedianFilter(filteredRawData, ((CapSense_1_TPSettings *) ptr)->Raw1Median[filterPos], ((CapSense_1_TPSettings *) ptr)->Raw2Median[filterPos]);
                       ((CapSense_1_TPSettings *) ptr)->Raw2Median[filterPos] = ((CapSense_1_TPSettings *) ptr)->Raw1Median[filterPos];
                    ((CapSense_1_TPSettings *) ptr)->Raw1Median[filterPos] = baseRawData;
                }
                
                /* Averaging filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_AveragingFilter(filteredRawData, ((CapSense_1_TPSettings *) ptr)->Raw1Averaging[filterPos], ((CapSense_1_TPSettings *) ptr)->Raw2Averaging[filterPos]);
                    ((CapSense_1_TPSettings *) ptr)->Raw2Averaging[filterPos] = ((CapSense_1_TPSettings *) ptr)->Raw1Averaging[filterPos];
                    ((CapSense_1_TPSettings *) ptr)->Raw1Averaging[filterPos] = baseRawData;
                }
                
                /* IIR filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_TPSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_0);
                    ((CapSense_1_TPSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                }
                else if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_TPSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_1);
                    ((CapSense_1_TPSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                }
                
                /* Jitter filter */
                if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                {
                    baseRawData = filteredRawData;
                    filteredRawData = CapSense_1_CSHL_JitterFilter(filteredRawData, ((CapSense_1_TPSettings *) ptr)->RawJitter[filterPos]);
                    ((CapSense_1_TPSettings *) ptr)->RawJitter[filterPos] = baseRawData;
                }
                break;
                
            case CapSense_1_CSHL_TYPE_MATRIX_BUTTONS:
                if(CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings)
                {
                ptr = CapSense_1_CSHL_WidgetTable[widget].AdvancedSettings;
                
                    /* Median filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_MEDIAN_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_MedianFilter(filteredRawData, ((CapSense_1_MBSettings *) ptr)->Raw1Median[filterPos], ((CapSense_1_MBSettings *) ptr)->Raw2Median[filterPos]);
                        ((CapSense_1_MBSettings *) ptr)->Raw2Median[filterPos] = ((CapSense_1_MBSettings *) ptr)->Raw1Median[filterPos];
                        ((CapSense_1_MBSettings *) ptr)->Raw1Median[filterPos] = baseRawData;
                    }
                    
                    /* Averaging filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_AVERAGING_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_AveragingFilter(filteredRawData, ((CapSense_1_MBSettings *) ptr)->Raw1Averaging[filterPos], ((CapSense_1_MBSettings *) ptr)->Raw2Averaging[filterPos]);
                        ((CapSense_1_MBSettings *) ptr)->Raw2Averaging[filterPos] = ((CapSense_1_MBSettings *) ptr)->Raw1Averaging[filterPos];
                        ((CapSense_1_MBSettings *) ptr)->Raw1Averaging[filterPos] = baseRawData;                
                    }
                    
                    /* IIR filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_0)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_MBSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_0);
                        ((CapSense_1_MBSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                    }
                    else if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_IIR_FILTER_1)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_IIRFilter(filteredRawData, ((CapSense_1_MBSettings *) ptr)->RawIIR[filterPos], CapSense_1_CSHL_IIR_FILTER_1);
                        ((CapSense_1_MBSettings *) ptr)->RawIIR[filterPos] = baseRawData;
                    }
                    
                    /* Jitter filter */
                    if(CapSense_1_CSHL_WidgetTable[widget].Filters & CapSense_1_CSHL_RAW_JITTER_FILTER)
                    {
                        baseRawData = filteredRawData;
                        filteredRawData = CapSense_1_CSHL_JitterFilter(filteredRawData, ((CapSense_1_MBSettings *) ptr)->RawJitter[filterPos]);
                        ((CapSense_1_MBSettings *) ptr)->RawJitter[filterPos] = baseRawData;
                    }
                }
                break;
                
            default:
                
                break;
        }
        
        /* Baseline calculation */
        CapSense_1_SlotResult[rawIndex] = filteredRawData;
        
        /* Find the Signal */
        temp = ( (int32) filteredRawData) - ( (int32) CapSense_1_CSHL_SlotBaseline[rawIndex]);
        if (temp < 0)
        {
            /* RawData less that Baseline */
            CapSense_1_CSHL_SlotSignal[rawIndex] = 0;
        }
        
        /* Update Baseline if lower that NoiseThreshold */
        if (temp < CapSense_1_CSHL_WidgetTable[widget].NoiseThreshold)
        {
            /* make full Baseline 23 bits */;
            temp = ((((uint32) CapSense_1_CSHL_SlotBaseline[rawIndex]) << 8) | ((uint32) CapSense_1_CSHL_SlotBaselineLow[rawIndex]));
            
            /* add Raw Data to Baseline */
              temp += filteredRawData;
            
            /* sub the high Baseline */
            temp -= CapSense_1_CSHL_SlotBaseline[rawIndex];
            
            /* Put Baseline and BaselineLow */
            CapSense_1_CSHL_SlotBaselineLow[rawIndex] = ((uint8) temp);
            CapSense_1_CSHL_SlotBaseline[rawIndex] = ((uint16) (temp >> 8));
            
            /* Signal is zero */
            CapSense_1_CSHL_SlotSignal[rawIndex] = 0;
        }
        else
        {
            temp -= CapSense_1_CSHL_WidgetTable[widget].NoiseThreshold;
            
            if(temp < 0xFFu)
            {
                CapSense_1_CSHL_SlotSignal[rawIndex] = (uint8) temp;
            }
            else
            {
                CapSense_1_CSHL_SlotSignal[rawIndex] = 0xFFu;
            }
        }
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_UpdateAllBaselines
********************************************************************************
*
* Summary:
*  Uses the CapSense_1_CSHL_UpdateSlotBaselines function to update
*  baselines for all slots. Raw data filters are applied to the values if
*  enabled.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
 void CapSense_1_CSHL_UpdateAllBaselines(void)
{
    uint8 i;
    
    for(i = 0; i < CapSense_1_TOTAL_SCANSLOT_COUNT; i++)
    {
        CapSense_1_CSHL_UpdateSlotBaseline(i);
    }
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_CheckIsSlotActive
********************************************************************************
*
* Summary:
*  Compares the selected slot of the CapSense_CSHL_Signal[ ] array to its finger
*  threshold. Hysteresis and Debounce are taken into account. The Hysteresis value
*  is added or subtracted from the finger threshold based on whether the slot is
*  currently active. If the slot is active, the threshold is lowered by the
*  hysteresis amount. If it is inactive, the threshold is raised by the
*  hysteresis amount. The Debounce counter added to the slot active transition.
*  This function also updates the slot's bit in the
*  CapSense_1_CSHL_SlotOnMask[ ] array
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  Returns scan slot state 1 if active, 0 if inactive
*
*******************************************************************************/
uint8 CapSense_1_CSHL_CheckIsSlotActive(uint8 slot)
{
    uint8 rawIndex = CapSense_1_ScanSlotTable[slot].RawIndex;
    uint8 widget = CapSense_1_ScanSlotTable[slot].WidgetNumber;
    uint8 onMask = 0x01u;
    
    if( widget != CapSense_1_CSHL_NO_WIDGET)
    {
        /* Get On/Off mask */
        onMask <<= (rawIndex % 8);
        
        /* Was on */
        if (CapSense_1_CSHL_SlotOnMask[(rawIndex)/8] & onMask)
        {
            /* Hysteresis minus */
            if (CapSense_1_CSHL_SlotSignal[rawIndex] < (CapSense_1_CSHL_WidgetTable[widget].FingerThreshold - CapSense_1_CSHL_WidgetTable[widget].Hysteresis))
            {
                CapSense_1_CSHL_SlotOnMask[(rawIndex)/8] &= ~onMask;
                CapSense_1_ScanSlotTable[slot].DebounceCount = CapSense_1_CSHL_WidgetTable[widget].Debounce;
            }
        }
        else    /* Was off */
        {
            /* Hysteresis plus */
            if (CapSense_1_CSHL_SlotSignal[rawIndex] > (CapSense_1_CSHL_WidgetTable[widget].FingerThreshold + CapSense_1_CSHL_WidgetTable[widget].Hysteresis))
            {
                if (CapSense_1_ScanSlotTable[slot].DebounceCount-- == 0)
                {
                    /* Slot active */
                    CapSense_1_CSHL_SlotOnMask[rawIndex/8] |= onMask;
                }
            }
            else
            {
                /* Slot inactive - reset Debounce count  */
                CapSense_1_ScanSlotTable[slot].DebounceCount = CapSense_1_CSHL_WidgetTable[widget].Debounce;
            }
        }
    }
    
    return (CapSense_1_CSHL_SlotOnMask[rawIndex/8] & onMask) ? 1 : 0;
}


/*******************************************************************************
* Function Name: CapSense_1_CSHL_CheckIsAnySlotActive
********************************************************************************
*
* Summary:
*  Compares all slots of the CapSense_CSHL_Signal[ ] array to their finger
*  threshold. Calls CapSense_1_CSHL_CheckIsAnySlotActive for each slot so
*  the CapSense_CSHL_SlotOnMask[ ] array is up to date after calling this
*  function.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  Returns 1 if any scan slot is active, 0 none of scan slots are active
*
*******************************************************************************/
uint8 CapSense_1_CSHL_CheckIsAnySlotActive(void)
{
    uint8 i, result = 0;
    
    for(i = 0; i < CapSense_1_TOTAL_SCANSLOT_COUNT; i++)
    {
        if (CapSense_1_CSHL_CheckIsSlotActive(i) == CapSense_1_CSHL_SLOT_ACTIVE)
        {
            result = CapSense_1_CSHL_SLOT_ACTIVE;
        }
    }
    
    return result;
}





/* [] END OF FILE */
