/*******************************************************************************
* File Name: HS_OUT.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "HS_OUT.h"


/*******************************************************************************
* Function Name: HS_OUT_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void HS_OUT_Write(uint8 value)
{
    uint8 staticBits = HS_OUT_DR & ~HS_OUT_MASK;
    HS_OUT_DR = staticBits | ((value << HS_OUT_SHIFT) & HS_OUT_MASK);
}


/*******************************************************************************
* Function Name: HS_OUT_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void HS_OUT_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(HS_OUT_0, mode);
}


/*******************************************************************************
* Function Name: HS_OUT_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro HS_OUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 HS_OUT_Read(void)
{
    return (HS_OUT_PS & HS_OUT_MASK) >> HS_OUT_SHIFT;
}


/*******************************************************************************
* Function Name: HS_OUT_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 HS_OUT_ReadDataReg(void)
{
    return (HS_OUT_DR & HS_OUT_MASK) >> HS_OUT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(HS_OUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: HS_OUT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 HS_OUT_ClearInterrupt(void)
    {
        return (HS_OUT_INTSTAT & HS_OUT_MASK) >> HS_OUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
